#
# spec file for package libcosmos
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define commit a8e6f94

Name:           libcosmos
Version:        0.2
Release:        5.2
Summary:        A library providing a modern C++ API for the Linux operating system
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/gerstner-hub/libcosmos
Source0:        libcosmos-0.2.0+git%{commit}.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  scons

%description
This is libcosmos, a library providing a modern C++ API for the Linux
operating system. It is intended for low level systems programming on Linux,
while relying on a strong C++ type model for robustness and expressiveness.

%package -n libcosmos-0_2_0
Summary:        A library providing a modern C++ API for the Linux operating system
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libcosmos-0_2_0
A library providing a modern C++ API for the Linux operating system.

The runtime library files for libcosmos.

%package devel
Summary:        A library providing a modern C++ API for the Linux operating system
Group:          Development/Libraries/C and C++
Requires:       libcosmos-0_2_0 = %{version}
Requires:       libstdc++-devel

%description devel
A library providing a modern C++ API for the Linux operating system.

Header and development files for libcosmos.

%prep
%setup -q -n %{name}-0.2.0+git%{commit}

%build
scons libtype=shared

%install
scons install instroot=%{buildroot}/usr

# some of the tests rely on networking so skip them for now
#%%check
#scons run_tests

%ldconfig_scriptlets -n libcosmos-0_2_0

%files -n libcosmos-0_2_0
%license LICENSE
%doc README.md
%{_libdir}/libcosmos.so.*

%files devel
%{_libdir}/libcosmos.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/cosmos/

%changelog
* Wed Mar  6 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+gita8e6f94:
  * GroupInfo: fix system include style
  * global: use angle bracket includes for libcosmos
  * string.hxx: add wide-string variant for to_lower(), to_upper()
  * string.hxx. support wide string strip() operation
  * byte_order: add default constructor for EndianNumber
- this fixes a broken -debugsource package generation
* Wed Feb 21 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+gitff219ee:
  * ILogger: support a prefix() to be added to each log message
  * ILogger: use more robust way to detect std::cout and std::cerr
  * trivial: SocketAddress: remove superfluous slash in comment
* Fri Feb 16 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+git7f2b8ee:
  * formatting: export another definition missing on 32-bit archs
  * scripts: use single quotes throughout
  * check.py: build all targets
  * buildsystem: support disabling doc build
  * check.py: select proper root directory for non-libcosmos projects
  * buildsystem: use single quotes throughout
  * buildsystem: use -fdiagnostics-color=auto instead of colorgcc wrapper
  * python files: incorporate Flake8 findings
  * check.py: also fun flake8 on Python files
  * buildsystem: support including local libraries with fallback to system pkg
  * PosixThread: fix race condition in setting m_pthread
  * buildsystem: support configuring default library type for project
* Tue Feb 13 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+git33d893b:
  * buildsystem: support transparent use of local lib or system lib
* Mon Feb  5 2024 matthias.gerstner@suse.com
- Update to version c4e5e5e:
  * SecretFile: fix compilation path where SYS_memfd_secret is not defined
* Fri Feb  2 2024 matthias.gerstner@suse.com
- Update to version b459a4d:
  * check: also build 32-bit configurations
  * FileDescriptor: fix fcntl(F_DUPFD_CLOEXEC) API
  * tests: formatting: use proper format string (triggers warning on 32-bit)
  * formatting: properly instantiate on 32-bit machines
  * buildsystem: support LDFLAGS extension
  * buildsystem: ensure we get a 64-bit off_t on Linux even on 32-bit machines
  * clone: fix cast of pidfd pointer for 32-bit platforms
  * DirEntry: use off_t for DirPos
* Wed Jan 31 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- initial packaging
